@@ -29,7 +29,7 @@
  * metrics field and --afm-path.
  *
  * */
-
+#include "config.h"
 #include <gnome.h>
 #include <dirent.h>
 #include <sys/stat.h>
@@ -37,7 +37,7 @@
 #include <errno.h>
 #include <gnome-xml/tree.h>
 #include <gnome-xml/parser.h>
-#include "config.h"
+#include <gnome-xml/xmlmemory.h>
 
 /* This program does not delete everything it allocates since it's
    just an installer program. */
@@ -104,7 +104,7 @@ xmlGetValue (xmlNodePtr node, const char *name)
     {
       char *gret;
       gret = g_strdup (ret);
-      free (ret);
+      xmlFree (ret);
       return gret;
     }
 
@@ -139,7 +139,7 @@ xmlSetValue (xmlNodePtr node, const char *name, const char *val)
   ret = xmlGetProp (node, name);
   if (ret != NULL)
     {
-      free (ret);
+      xmlFree (ret);
       xmlSetProp (node, name, val);
       return;
     }
@@ -609,8 +609,8 @@ warn_missing_font (const char *font_name)
 	     "for more information.", font_name);
 }
 
-gint
-main( gint argc, gchar *argv[])
+int
+main (int argc, char *argv[])
 {
   xmlDoc *fontmap;
   GString *fontmap_file = NULL;
@@ -665,7 +665,11 @@ main( gint argc, gchar *argv[])
     }
   if ( scan_dot )
     scan_fonts( fontmap, "." );
-  write_fontmap( fontmap, fontmap_loc );
+  if (write_fontmap( fontmap, fontmap_loc ) == -1)
+    {
+      fprintf (stderr, "Failed to write fontmap file (%s).\n", fontmap_loc);
+      return 1;
+    }
 
   poptFreeContext(ctx);
   xmlFreeDoc (fontmap);
