@@ -37,10 +37,13 @@ gnome_canvas_bpath_def_new_from (ArtBpath *path)
 
 	g_return_val_if_fail (path != NULL, NULL);
 
-	bpd = g_new (GnomeCanvasBpathDef, 1);
-	
 	for (i = 0; path [i].code != ART_END; i++)
 		;
+	if (i <= 0)
+		return gnome_canvas_bpath_def_new ();
+
+	bpd = g_new (GnomeCanvasBpathDef, 1);
+	
 	bpd->n_bpath = i;
 	bpd->n_bpath_max = i;
 	bpd->moveto_idx = -1;
