@@ -211,12 +211,12 @@ encode_header(GnomePrintMeta *pc, GnomeMetaFileHeader *mh)
 static void
 close_page_header(GnomePrintMeta *pc)
 {
-	gint32 *sizeptr;
-
 	if (pc->priv->last_page != -1) {
+		gint32 l;
+		l = g_htonl(pc->current - pc->priv->last_page - PAGEHEADER_SIZE);
 		/* we cannot map the page header back into memory, so poke it back in */
-		sizeptr = (gint32 *)((pc->buffer + pc->priv->last_page) + 4);
-		*sizeptr = g_htonl(pc->current - pc->priv->last_page - PAGEHEADER_SIZE);
+		/* Note: unaligned access -- MW.  */
+		memcpy ((pc->buffer + pc->priv->last_page) + 4, &l, sizeof (l));
 	}
 }
 
@@ -483,12 +483,15 @@ meta_showpage (GnomePrintContext *pc)
 static int
 meta_close (GnomePrintContext *pc)
 {
+	gint32 l;
 	GnomePrintMeta *meta = GNOME_PRINT_META (pc);
 
 	encode_int (pc, GNOME_META_CLOSE);
 
+	l = g_htonl (meta->buffer_size);
 	/* we cannot just map the header to memory, so poke it manually */
-	*((gint32 *)(meta->buffer+GNOME_METAFILE_SIGNATURE_SIZE)) = g_htonl(meta->buffer_size);
+	/* Note: unaligned access -- MW.  */
+	memcpy (meta->buffer + GNOME_METAFILE_SIGNATURE_SIZE, &l, sizeof (l));
 
 	return 0;
 }
@@ -782,16 +785,14 @@ decode_page_header (const char *data, GnomeMetaPageHeader *mh)
 static const char *
 locate_page_header(const char *meta_stream, int page)
 {
-	const char *data = meta_stream + FILEHEADER_SIZE;
+	const char *data = meta_stream + FILEHEADER_SIZE, *next;
 	GnomeMetaPageHeader page_header;
 
-	while (page>0) {
+	next = decode_page_header(data, &page_header);
+	while (page>0 && page_header.size != -1) {
+		data = next + page_header.size;
+		next = decode_page_header(data, &page_header);
 		page--;
-		data = decode_page_header(data, &page_header);
-		/* unclosed or last page? */
-		if (page_header.size == -1)
-			return NULL;
-		data += page_header.size;
 	}
 	if (page_header.size == -1)
 		return NULL;
