@@ -5,7 +5,7 @@
  * Author:
  *   Miguel de Icaza (miguel@gnu.org)
  *
- * (C) 1999 International GNOME Support
+ * (C) 1999, 2000 International GNOME Support
  */
 #include <config.h>
 #include <gtk/gtk.h>
@@ -66,12 +66,7 @@ struct _GnomePrintPreviewPrivate {
 	/* The current page */
 	GnomeCanvasItem *page;
 	
-	/* An array of GnomeCanvasItemGroups */
-	GArray *pages;
-
 	GHashTable *font_hash;
-
-	GnomeCanvasItem *auto_hide_page_on_stroke;
 };
 
 #define gc(o) ((GraphicContext *)((o)->context_list->data))
@@ -159,22 +154,6 @@ dump_gc (GnomePrintPreview *pp)
 	}
 }
 
-/*
- * This just enables us to avoid doing a control of the page/display
- * when the job is finished (for the sample applications).
- *
- * ie, we are delaying showpage's item_hide on the page until the first
- * output command for the next page.
- */
-static void
-lazy_showpage_check (GnomePrintPreviewPrivate *priv)
-{
-	if (priv->auto_hide_page_on_stroke) {
-		gnome_canvas_item_hide (priv->auto_hide_page_on_stroke);
-		priv->auto_hide_page_on_stroke = NULL;
-	}
-}
-
 static int
 gpp_newpath (GnomePrintContext *pc)
 {
@@ -312,7 +291,7 @@ gpp_stroke (GnomePrintContext *pc)
 
 	if (close)
 		close_path (g->bpath);
-	lazy_showpage_check (priv);
+
 	item = gnome_canvas_item_new (g->group,
 		gnome_canvas_bpath_get_type (),
 		"bpath",       g->bpath,
@@ -337,7 +316,7 @@ gpp_strokepath (GnomePrintContext *pc)
 
 	close_path (gc (priv)->bpath);
 	g_warning ("Strokepath is not tested");
-	lazy_showpage_check (priv);
+
 	item = gnome_canvas_item_new (
 		gc (priv)->group,
 		gnome_canvas_bpath_get_type (),
@@ -361,7 +340,7 @@ gpp_fill (GnomePrintContext *pc)
 	g_return_val_if_fail (gc (priv)->bpath != NULL, -1);
 
 	close_path (gc (priv)->bpath);
-	lazy_showpage_check (priv);
+
 	item = gnome_canvas_item_new (
 		gc (priv)->group,
 		gnome_canvas_bpath_get_type (),
@@ -488,6 +467,9 @@ gnome_canvas_bpath_def_duplicate (GnomeCanvasBpathDef *def)
 
 	g_return_val_if_fail (def != NULL, NULL);
 
+	if (def->n_bpath <= 0)
+		return gnome_canvas_bpath_def_new ();
+
 	bpd = g_new (GnomeCanvasBpathDef, 1);
 	
 	bpd->n_bpath = def->n_bpath;
@@ -632,7 +614,6 @@ gpp_image (GnomePrintContext *pc, const char *data, int width, int height, int r
 	} else
 		return -1;
 
-	lazy_showpage_check (priv);
 	item = gnome_canvas_item_new (
 		g->group,
 		gnome_canvas_image_get_type (),
@@ -689,22 +670,6 @@ gpp_showpage (GnomePrintContext *pc)
 	GnomePrintPreview *pp = GNOME_PRINT_PREVIEW (pc);
 	GnomePrintPreviewPrivate *priv = pp->priv;
 
-	g_array_append_val (priv->pages, priv->page);
-
-	priv->auto_hide_page_on_stroke = priv->page;
-	
-	priv->page = gnome_canvas_item_new (
-		gnome_canvas_root (pp->canvas),
-		gnome_canvas_group_get_type (),
-		"x", 0.0,
-		"y", 0.0,
-		NULL);
-
-	/*
-	 * Setup base group
-	 */
-	gc (priv)->group = GNOME_CANVAS_GROUP (priv->page);
-
 	/*
 	 * Reset affine and path
 	 */
@@ -794,7 +759,6 @@ gpp_show (GnomePrintContext *pc, char const *text)
 	art_affine_invert (inverse, transform);
 	art_affine_point (&p, &p, inverse);
 
-	lazy_showpage_check (priv);
 	item = gnome_canvas_item_new (
 		g->group,
 		gnome_canvas_hacktext_get_type (),
@@ -838,7 +802,7 @@ kill_font (gpointer key, gpointer value, gpointer user_data)
 }
 
 static void
-gpp_finalize (GtkObject *object)
+gpp_destroy (GtkObject *object)
 {
 	GnomePrintPreview *pp = GNOME_PRINT_PREVIEW (object);
 	GnomePrintPreviewPrivate *priv = pp->priv;
@@ -848,7 +812,7 @@ gpp_finalize (GtkObject *object)
 	for (l = priv->context_list; l; l = l->next)
 		gc_free (l->data);
 	g_slist_free (priv->context_list);
-	
+
 	if (pp->canvas)
 		gtk_object_unref (GTK_OBJECT (pp->canvas));
 
@@ -857,25 +821,14 @@ gpp_finalize (GtkObject *object)
 		g_hash_table_destroy (priv->font_hash);
 	}
 
-#if 0
-	for (i = 0; i < priv->pages->len; i++){
-		GnomeCanvasItem *page;
-		
-		page = g_array_index (priv->pages, GnomeCanvasItem *, i);
-		gtk_object_destroy (GTK_OBJECT (page));
-	}
-#endif
-
 	if (priv->page)
 		gtk_object_destroy (GTK_OBJECT (priv->page));
 
 	if (priv->root)
 		gtk_object_destroy (GTK_OBJECT (priv->root));
 	
-	g_array_free (priv->pages, TRUE);
-
 	g_free (priv);
-	GTK_OBJECT_CLASS (print_preview_parent_class)->finalize (object);
+	GTK_OBJECT_CLASS (print_preview_parent_class)->destroy (object);
 }
 
 static void
@@ -886,7 +839,7 @@ gpp_class_init (GnomePrintPreviewClass *class)
 
 	print_preview_parent_class = gtk_type_class (gnome_print_context_get_type ());
 
-	object_class->finalize = gpp_finalize;
+	object_class->destroy = gpp_destroy;
 	
 	pc_class->newpath = gpp_newpath;
 	pc_class->moveto = gpp_moveto;
@@ -935,8 +888,6 @@ gpp_init (GnomePrintPreview *preview)
 	gc (priv)->width = 1.0;
 	gc (priv)->linecap = GDK_CAP_BUTT;
 	gc (priv)->join = GDK_JOIN_MITER;
-
-	priv->pages = g_array_new (FALSE, FALSE, sizeof (GnomeCanvasItem *));
 }
 
 static void
@@ -1070,183 +1021,3 @@ gnome_print_preview_get_type (void)
 	return type;
 }
 
-/*
- *
- * GNOME Print Preview Object
- *
- */
-static GtkObjectClass *pjob_parent_class;
-
-struct _GnomePrintPreviewJobPrivate {
-	GArray          *pages;
-	int              last_page_shown;
-};
-
-static void
-pjob_finalize (GtkObject *object)
-{
-	GnomePrintPreviewJob *pjob = (GnomePrintPreviewJob *)(object);
-
-	gtk_object_unref (GTK_OBJECT (pjob->canvas));
-
-	g_array_free (pjob->priv->pages, TRUE);
-	g_free (pjob->priv);
-	
-	GTK_OBJECT_CLASS (pjob_parent_class)->finalize (object);
-}
-
-static void
-pjob_init (GtkObject *object)
-{
-	GnomePrintPreviewJob *pjob = GNOME_PRINT_PREVIEW_JOB (object);
-	
-	pjob->priv = g_new0 (GnomePrintPreviewJobPrivate, 1);
-	pjob->priv->last_page_shown = -1;
-}
-
-static void
-pjob_class_init (GtkObjectClass *object_class)
-{
-	object_class->finalize = pjob_finalize;
-
-	pjob_parent_class = gtk_type_class (gtk_object_get_type ());
-}
-
-/**
- * gnome_print_preview_job_get_type:
- *
- * GTK type identification routine for #GnomePrintPreviewJob
- *
- * Returns: The Gtk type for the #GnomePrintPreviewJob object
- */
-GtkType
-gnome_print_preview_job_get_type (void)
-{
-	static GtkType type = 0;
-
-	if (!type){
-		GtkTypeInfo info = {
-			"GnomePrintPreviewJob",
-			sizeof (GnomePrintPreviewJob),
-			sizeof (GnomePrintPreviewJobClass),
-			(GtkClassInitFunc) pjob_class_init,
-			(GtkObjectInitFunc) pjob_init,
-			/* reserved_1 */ NULL,
-			/* reserved_2 */ NULL,
-			(GtkClassInitFunc) NULL,
-		};
-		
-		type = gtk_type_unique (gtk_object_get_type (), &info);
-	}
-	return type;
-}
-
-/**
- * gnome_print_preview_job_construct:
- * @pjob: the #GnomePrintPreviewJob object to construct
- * @preview: The #GnomePrintPreview object that this job controls
- *
- * Constructs the @pjob object.
- */
-void
-gnome_print_preview_job_construct (GnomePrintPreviewJob *pjob, GnomePrintPreview *preview)
-{
-	int i, size;
-	
-	g_return_if_fail (preview != NULL);
-	g_return_if_fail (GNOME_IS_PRINT_PREVIEW (preview));
-	g_return_if_fail (pjob != NULL);
-	g_return_if_fail (GNOME_IS_PRINT_PREVIEW_JOB (pjob));
-
-	lazy_showpage_check (preview->priv);
-	gtk_object_ref (GTK_OBJECT (preview->canvas));
-	pjob->canvas = preview->canvas;
-	size = preview->priv->pages->len;
-	pjob->priv->pages = g_array_new (size, 0, sizeof (GnomeCanvasItem *));
-
-	for (i = 0; i < size; i++){
-		GnomeCanvasItem *item;
-		
-		item = g_array_index (preview->priv->pages, GnomeCanvasItem *, i);
-		g_array_append_val (pjob->priv->pages, item);
-	}
-
-}
-
-/**
- * gnome_print_preview_get_job:
- * @preview: A #GnomePrintPreview object.
- *
- * This routine returns a #GnomePrintPreviewJob object which enabled
- * you to control which page is being displayed in the @preview canvas.
- *
- * Returns: The #GnomePrintPreviewJob object associated with @preview.
- */
-GnomePrintPreviewJob *
-gnome_print_preview_get_job (GnomePrintPreview *preview)
-{
-	GnomePrintPreviewJob *pjob;
-	
-	g_return_val_if_fail (preview != NULL, NULL);
-	g_return_val_if_fail (GNOME_IS_PRINT_PREVIEW (preview), NULL);
-
-	pjob = gtk_type_new (gnome_print_preview_job_get_type ());
-
-	gnome_print_preview_job_construct (pjob, preview);
-
-	return pjob;
-}
-
-/**
- * gnome_print_preview_job_page_visible:
- * @pjob: #GnomePrintPreview object
- * @page: page to display, or -1 to not display any page.
- *
- * Displays the page @page.  
- */
-void
-gnome_print_preview_job_page_show (GnomePrintPreviewJob *pjob, int page)
-{
-	GnomeCanvasItem *item;
-	
-	g_return_if_fail (pjob != NULL);
-	g_return_if_fail (GNOME_IS_PRINT_PREVIEW_JOB (pjob));
-	g_return_if_fail (page >= 0);
-
-	if (page < 0)
-		return;
-
-	if (page >= pjob->priv->pages->len)
-		return;
-
-	if (pjob->priv->last_page_shown != -1){
-		GnomeCanvasItem *item;
-		
-		item = g_array_index (pjob->priv->pages, GnomeCanvasItem *, pjob->priv->last_page_shown);
-		gnome_canvas_item_hide (item);
-	}
-	
-	item = g_array_index (pjob->priv->pages, GnomeCanvasItem *, page);
-	gnome_canvas_item_show (item);
-
-	pjob->priv->last_page_shown = page;
-}
-
-int
-gnome_print_preview_job_num_pages (GnomePrintPreviewJob *pjob)
-{
-	g_return_val_if_fail (pjob != NULL, 0);
-	g_return_val_if_fail (GNOME_IS_PRINT_PREVIEW_JOB (pjob), 0);
-
-	return pjob->priv->pages->len;
-}
-
-int
-gnome_print_preview_job_current_page (GnomePrintPreviewJob *pjob)
-{
-	g_return_val_if_fail (pjob != NULL, 0);
-	g_return_val_if_fail (GNOME_IS_PRINT_PREVIEW_JOB (pjob), 0);
-
-	return pjob->priv->last_page_shown;
-}
-
