@@ -8,6 +8,7 @@
 #include <libgnomeprint/gnome-print-ps.h>
 #include <libgnomeprint/gnome-font.h>
 
+void gnome_print_ps_reencode_font (GnomePrintContext *pc, const char* fontname);
 
 static void gnome_print_ps_class_init (GnomePrintPsClass *klass);
 
@@ -241,6 +242,22 @@ gnome_print_ps_setfont_raw (GnomePrintContext *pc, GnomeFontUnsized *unsized,
 				   (ps->n_fonts_max <<= 1));
 	  ps->fonts[ps->n_fonts++] = g_strdup (fontname);
 	  g_free (pfa);
+	  gnome_print_ps_reencode_font (pc, fontname);
+	}
+    }
+  else
+    {
+      for (i = 0; i < ps->n_fonts_reencoded; i++)
+        if (!strcmp (fontname, ps->fonts_reencoded[i]))
+	  break;
+
+      if (i == ps->n_fonts_reencoded)
+        {
+          if (ps->n_fonts_reencoded == ps->n_fonts_reencoded_max)
+	    ps->fonts_reencoded = g_realloc (ps->fonts_reencoded, sizeof (char *) *
+				            (ps->n_fonts_reencoded_max <<= 1));
+	  ps->fonts_reencoded[ps->n_fonts_reencoded++] = g_strdup (fontname);
+          gnome_print_ps_reencode_font (pc, fontname);
 	}
     }
 
@@ -257,7 +274,7 @@ gnome_print_ps_setfont_raw (GnomePrintContext *pc, GnomeFontUnsized *unsized,
   /* FIXME: what about ->current_gnome_font?  */
 
   return gnome_print_context_fprintf (pc,
-				      "/%s findfont %g scalefont setfont\n",
+				      "/La-%s findfont %g scalefont setfont\n",
 				      fontname, size);
 
 }
@@ -303,6 +320,22 @@ gnome_print_ps_setfont (GnomePrintContext *pc, GnomeFont *font)
 				   (ps->n_fonts_max <<= 1));
 	  ps->fonts[ps->n_fonts++] = g_strdup (fontname);
 	  g_free (pfa);
+	  gnome_print_ps_reencode_font (pc, fontname);
+	}
+    }
+  else
+    {
+      for (i = 0; i < ps->n_fonts_reencoded; i++)
+        if (!strcmp (fontname, ps->fonts_reencoded[i]))
+	  break;
+
+      if (i == ps->n_fonts_reencoded)
+        {
+          if (ps->n_fonts_reencoded == ps->n_fonts_reencoded_max)
+	    ps->fonts_reencoded = g_realloc (ps->fonts_reencoded, sizeof (char *) *
+				            (ps->n_fonts_reencoded_max <<= 1));
+	  ps->fonts_reencoded[ps->n_fonts_reencoded++] = g_strdup (fontname);
+          gnome_print_ps_reencode_font (pc, fontname);
 	}
     }
 
@@ -324,11 +357,21 @@ gnome_print_ps_setfont (GnomePrintContext *pc, GnomeFont *font)
   ps->cur_size = 0;
 
   return gnome_print_context_fprintf (pc,
-				      "/%s findfont %g scalefont setfont\n",
+				      "/La-%s findfont %g scalefont setfont\n",
 				      fontname, font->size);
 
 }
 
+void
+gnome_print_ps_reencode_font (GnomePrintContext *pc, const char * fontname)
+{
+  gnome_print_context_fprintf (pc,"/%s findfont\ndup length dict begin\n"
+			       "{1 index /FID ne {def} {pop pop} ifelse}"
+			       "forall\n/Encoding ISOLatin1Encoding def\n"
+			       "currentdict\nend\n/La-%s exch definefont pop\n",
+			       fontname, fontname);
+}
+
 static int
 gnome_print_ps_show (GnomePrintContext *pc, char const *text)
 {
@@ -345,23 +388,26 @@ gnome_print_ps_show (GnomePrintContext *pc, char const *text)
 	  if (gnome_print_context_fprintf (pc, "\\%c", text[i]) < 0)
 	    return -1;
 	}
-      else if (isascii (text[i]))
-	{
-	  if (gnome_print_context_fprintf (pc, "%c", text[i]) < 0)
+      else if ( text[i] > 31 && text[i] < 127)
+        {
+          if (gnome_print_context_fprintf (pc, "%c", text[i]) < 0)
 	    return -1;
 	}
-      else
+      else if ( (unsigned char) text[i] == 153 || (unsigned char) text[i] == 156 ) 
 	{
-	  int c;
-	  c = gnome_font_get_glyph (ps->current_gnome_font,
-				    (unsigned char)(text[i]));
-	  if (c == -1)
-          {
-                  c = '*'; /* FIXME -- do something better for missing chars.  */
-                  g_print("\n*** Gnome-Print: gnome-print-ps.c  non-standard Char = %i\n", (unsigned char)text[i]);
-          }
-          
-	  if (gnome_print_context_fprintf (pc, "%c", c) < 0)
+          /* this chars are .notdef in isoLatin*/ 
+	  if (gnome_print_context_fprintf (pc," ") < 0)
+	    return -1;
+	}
+      else if ( (unsigned char) text[i] > 143 )
+        {
+          if (gnome_print_context_fprintf (pc, "%c", (unsigned char) text[i]) < 0)
+	    return -1;
+	}
+      else 
+	{
+	     /* .notdef char */
+	  if (gnome_print_context_fprintf (pc, " ") < 0)
 	    return -1;
 	}
     }
@@ -697,13 +743,16 @@ gnome_print_ps_init (GnomePrintPs *ps)
   int i;
 
   ps->n_fonts = 0;
+  ps->n_fonts_reencoded = 0;
   ps->n_fonts_max = 16;
+  ps->n_fonts_reencoded_max = 10;
   ps->fonts = g_new (char *, ps->n_fonts_max);
 
   ps->n_builtins = sizeof(gnome_print_ps_builtins) / sizeof(char *);
   ps->n_builtins_max = sizeof(gnome_print_ps_builtins) / sizeof(char *);
   ps->builtins = g_new (char *, ps->n_builtins_max);
 
+  ps->fonts_reencoded = g_new (char *, ps->n_fonts_reencoded_max);
   for (i = 0; i < sizeof(gnome_print_ps_builtins) / sizeof(char *); i++)
     ps->builtins[i] = gnome_print_ps_builtins[i];
 
@@ -767,8 +816,13 @@ gnome_print_ps_finalize (GtkObject *object)
 
   for (i = 0; i < ps->n_fonts; i++)
     g_free (ps->fonts[i]);
+
+  for (i = 0; i < ps->n_fonts_reencoded; i++)
+    g_free (ps->fonts_reencoded[i]);
+
   g_free (ps->fonts);
   g_free (ps->builtins);
+  g_free (ps->fonts_reencoded);
 
   (* GTK_OBJECT_CLASS (parent_class)->finalize) (object);
 }
