@@ -98,6 +98,10 @@ gnome_print_context_init (GnomePrintContext *pc)
 GnomePrintContext *
 gnome_print_context_new_with_paper_size (GnomePrinter *printer, const char *paper_size)
 {
+	g_return_val_if_fail (printer != NULL, NULL);
+	g_return_val_if_fail (GNOME_IS_PRINTER (printer), NULL);
+	g_return_val_if_fail (paper_size != NULL, NULL);
+
 	if (strcmp (printer->driver, "gnome-print-ps") == 0) {
 		GnomePrintPs *ps = gnome_print_ps_new (printer);
 		return ps ? GNOME_PRINT_CONTEXT (ps) : NULL;
@@ -120,6 +124,8 @@ gnome_print_context_new_with_paper_size (GnomePrinter *printer, const char *pape
 GnomePrintContext *
 gnome_print_context_new (GnomePrinter *printer)
 {
+	g_return_val_if_fail (printer != NULL, NULL);
+
 	return gnome_print_context_new_with_paper_size (printer, "US-Letter");
 }
 
@@ -143,132 +149,205 @@ gnome_print_context_finalize (GtkObject *object)
 int
 gnome_print_newpath (GnomePrintContext *pc)
 {
+	g_return_val_if_fail (pc != NULL, -1);
+	g_return_val_if_fail (GNOME_IS_PRINT_CONTEXT (pc), -1);
+
 	return PRINT_CLASS(pc)->newpath (pc);
 }
 
 int
 gnome_print_moveto (GnomePrintContext *pc, double x, double y)
 {
+	g_return_val_if_fail (pc != NULL, -1);
+	g_return_val_if_fail (GNOME_IS_PRINT_CONTEXT (pc), -1);
+
 	return PRINT_CLASS(pc)->moveto (pc, x, y);
 }
 
 int
 gnome_print_lineto (GnomePrintContext *pc, double x, double y)
 {
+	g_return_val_if_fail (pc != NULL, -1);
+	g_return_val_if_fail (GNOME_IS_PRINT_CONTEXT (pc), -1);
+
 	return PRINT_CLASS(pc)->lineto (pc, x, y);
 }
 
 int
 gnome_print_curveto (GnomePrintContext *pc, double x1, double y1, double x2, double y2, double x3, double y3)
 {
+	g_return_val_if_fail (pc != NULL, -1);
+	g_return_val_if_fail (GNOME_IS_PRINT_CONTEXT (pc), -1);
+
 	return PRINT_CLASS(pc)->curveto (pc, x1, y1, x2, y2, x3, y3);
 }
 
 int
 gnome_print_closepath (GnomePrintContext *pc)
 {
+	g_return_val_if_fail (pc != NULL, -1);
+	g_return_val_if_fail (GNOME_IS_PRINT_CONTEXT (pc), -1);
+
 	return PRINT_CLASS(pc)->closepath (pc);
 }
 
 int
 gnome_print_setrgbcolor (GnomePrintContext *pc, double r, double g, double b)
 {
+	g_return_val_if_fail (pc != NULL, -1);
+	g_return_val_if_fail (GNOME_IS_PRINT_CONTEXT (pc), -1);
+
 	return PRINT_CLASS(pc)->setrgbcolor (pc, r, g, b);
 }
 
 int
 gnome_print_fill (GnomePrintContext *pc)
 {
+	g_return_val_if_fail (pc != NULL, -1);
+	g_return_val_if_fail (GNOME_IS_PRINT_CONTEXT (pc), -1);
+
 	return PRINT_CLASS(pc)->fill (pc);
 }
 
 int
 gnome_print_eofill (GnomePrintContext *pc)
 {
+	g_return_val_if_fail (pc != NULL, -1);
+	g_return_val_if_fail (GNOME_IS_PRINT_CONTEXT (pc), -1);
+
 	return PRINT_CLASS(pc)->eofill (pc);
 }
 
 int
 gnome_print_setlinewidth (GnomePrintContext *pc, double width)
 {
+	g_return_val_if_fail (pc != NULL, -1);
+	g_return_val_if_fail (GNOME_IS_PRINT_CONTEXT (pc), -1);
+
 	return PRINT_CLASS(pc)->setlinewidth (pc, width);
 }
 
 int
 gnome_print_setmiterlimit (GnomePrintContext *pc, double limit)
 {
+	g_return_val_if_fail (pc != NULL, -1);
+	g_return_val_if_fail (GNOME_IS_PRINT_CONTEXT (pc), -1);
+
 	return PRINT_CLASS(pc)->setmiterlimit (pc, limit);
 }
 
 int
 gnome_print_setlinejoin (GnomePrintContext *pc, int jointype)
 {
+	g_return_val_if_fail (pc != NULL, -1);
+	g_return_val_if_fail (GNOME_IS_PRINT_CONTEXT (pc), -1);
+
 	return PRINT_CLASS(pc)->setlinejoin (pc, jointype);
 }
 
 int
 gnome_print_setlinecap (GnomePrintContext *pc, int captype)
 {
+	g_return_val_if_fail (pc != NULL, -1);
+	g_return_val_if_fail (GNOME_IS_PRINT_CONTEXT (pc), -1);
+
 	return PRINT_CLASS(pc)->setlinecap (pc, captype);
 }
 
 int
 gnome_print_setdash (GnomePrintContext *pc, int n_values, const double *values, double offset)
 {
+	g_return_val_if_fail (pc != NULL, -1);
+	g_return_val_if_fail (GNOME_IS_PRINT_CONTEXT (pc), -1);
+
+	if (n_values != 0)
+		g_return_val_if_fail (values != NULL, -1);
+
 	return PRINT_CLASS(pc)->setdash (pc, n_values, values, offset);
 }
 
 int
 gnome_print_strokepath (GnomePrintContext *pc)
 {
+	g_return_val_if_fail (pc != NULL, -1);
+	g_return_val_if_fail (GNOME_IS_PRINT_CONTEXT (pc), -1);
+
 	return PRINT_CLASS(pc)->strokepath (pc);
 }
 
 int
 gnome_print_stroke (GnomePrintContext *pc)
 {
+	g_return_val_if_fail (pc != NULL, -1);
+	g_return_val_if_fail (GNOME_IS_PRINT_CONTEXT (pc), -1);
+
 	return PRINT_CLASS(pc)->stroke (pc);
 }
 
 int
 gnome_print_setfont (GnomePrintContext *pc, GnomeFont *font)
 {
+	g_return_val_if_fail (pc != NULL, -1);
+	g_return_val_if_fail (GNOME_IS_PRINT_CONTEXT (pc), -1);
+	g_return_val_if_fail (font != NULL, -1);
+
 	return PRINT_CLASS(pc)->setfont (pc, font);
 }
 
 int
 gnome_print_show (GnomePrintContext *pc, char const *text)
 {
+	g_return_val_if_fail (pc != NULL, -1);
+	g_return_val_if_fail (GNOME_IS_PRINT_CONTEXT (pc), -1);
+	g_return_val_if_fail (text != NULL, -1);
+
 	return PRINT_CLASS(pc)->show (pc, text);
 }
 
 int
 gnome_print_concat (GnomePrintContext *pc, const double matrix[6])
 {
+	g_return_val_if_fail (pc != NULL, -1);
+	g_return_val_if_fail (GNOME_IS_PRINT_CONTEXT (pc), -1);
+	g_return_val_if_fail (matrix != NULL, -1);
+
 	return PRINT_CLASS(pc)->concat (pc, matrix);
 }
 
 int
 gnome_print_setmatrix (GnomePrintContext *pc, const double matrix[6])
 {
+	g_return_val_if_fail (pc != NULL, -1);
+	g_return_val_if_fail (GNOME_IS_PRINT_CONTEXT (pc), -1);
+	g_return_val_if_fail (matrix != NULL, -1);
+
 	return PRINT_CLASS(pc)->setmatrix (pc, matrix);
 }
 
 int
 gnome_print_gsave (GnomePrintContext *pc)
 {
+	g_return_val_if_fail (pc != NULL, -1);
+	g_return_val_if_fail (GNOME_IS_PRINT_CONTEXT (pc), -1);
+
 	return PRINT_CLASS(pc)->gsave (pc);
 }
 
 int
 gnome_print_grestore (GnomePrintContext *pc)
 {
+	g_return_val_if_fail (pc != NULL, -1);
+	g_return_val_if_fail (GNOME_IS_PRINT_CONTEXT (pc), -1);
+
 	return PRINT_CLASS(pc)->grestore (pc);
 }
 
 int
 gnome_print_clip (GnomePrintContext *pc)
 {
+	g_return_val_if_fail (pc != NULL, -1);
+	g_return_val_if_fail (GNOME_IS_PRINT_CONTEXT (pc), -1);
+
 	return PRINT_CLASS(pc)->clip (pc);
 }
 
@@ -281,30 +360,48 @@ gnome_print_eoclip (GnomePrintContext *pc)
 int
 gnome_print_grayimage (GnomePrintContext *pc, const char *data, int width, int height, int rowstride)
 {
+	g_return_val_if_fail (pc != NULL, -1);
+	g_return_val_if_fail (GNOME_IS_PRINT_CONTEXT (pc), -1);
+	g_return_val_if_fail (data != NULL, -1);
+
 	return PRINT_CLASS(pc)->grayimage (pc, data, width, height, rowstride);
 }
 
 int
 gnome_print_rgbimage (GnomePrintContext *pc, const char *data, int width, int height, int rowstride)
 {
+	g_return_val_if_fail (pc != NULL, -1);
+	g_return_val_if_fail (GNOME_IS_PRINT_CONTEXT (pc), -1);
+	g_return_val_if_fail (data != NULL, -1);
+
 	return PRINT_CLASS(pc)->rgbimage (pc, data, width, height, rowstride);
 }
 
 int
 gnome_print_textline (GnomePrintContext *pc, GnomeTextLine *line)
 {
+	g_return_val_if_fail (pc != NULL, -1);
+	g_return_val_if_fail (GNOME_IS_PRINT_CONTEXT (pc), -1);
+	g_return_val_if_fail (line != NULL, -1);
+
 	return PRINT_CLASS(pc)->textline (pc, line);
 }
 
 int
 gnome_print_showpage (GnomePrintContext *pc)
 {
+	g_return_val_if_fail (pc != NULL, -1);
+	g_return_val_if_fail (GNOME_IS_PRINT_CONTEXT (pc), -1);
+
 	return PRINT_CLASS(pc)->showpage (pc);
 }
 
 int
 gnome_print_setopacity (GnomePrintContext *pc, double opacity)
 {
+	g_return_val_if_fail (pc != NULL, -1);
+	g_return_val_if_fail (GNOME_IS_PRINT_CONTEXT (pc), -1);
+
 	return PRINT_CLASS(pc)->setopacity (pc, opacity);
 }
 
@@ -324,6 +421,9 @@ gnome_print_scale (GnomePrintContext *pc, double sx, double sy)
 {
 	double dst[6];
 
+	g_return_val_if_fail (pc != NULL, -1);
+	g_return_val_if_fail (GNOME_IS_PRINT_CONTEXT (pc), -1);
+
 	art_affine_scale (dst, sx, sy);
 	return gnome_print_concat (pc, dst);
 }
@@ -333,6 +433,9 @@ gnome_print_rotate (GnomePrintContext *pc, double theta)
 {
 	double dst[6];
 
+	g_return_val_if_fail (pc != NULL, -1);
+	g_return_val_if_fail (GNOME_IS_PRINT_CONTEXT (pc), -1);
+
 	art_affine_rotate (dst, theta);
 	return gnome_print_concat (pc, dst);
 }
@@ -342,6 +445,9 @@ gnome_print_translate (GnomePrintContext *pc, double x, double y)
 {
 	double dst[6];
 
+	g_return_val_if_fail (pc != NULL, -1);
+	g_return_val_if_fail (GNOME_IS_PRINT_CONTEXT (pc), -1);
+
 	art_affine_translate (dst, x, y);
 	return gnome_print_concat (pc, dst);
 }
@@ -358,6 +464,7 @@ gnome_print_context_open_file (GnomePrintContext *pc, const char *filename)
 {
 	g_return_val_if_fail (pc != NULL, -1);
 	g_return_val_if_fail (GNOME_IS_PRINT_CONTEXT (pc), -1);
+	g_return_val_if_fail (filename != NULL, -1);
 
 	if (filename[0] == '|')
 	{
@@ -537,4 +644,3 @@ gnome_print_vpath (GnomePrintContext * gpc, ArtVpath * vpath, gboolean append)
 		gnome_print_closepath (gpc);
 
 }
-
