@@ -1273,14 +1273,16 @@ parseFileFree (Font_Info *fi)
      if (fi->cmi) {
 	  int i;
 	  for (i = 0; i < fi->numOfChars; i++) {
+	       Ligature *ligs;
 	       free (fi->cmi[i].name);
-	       while (fi->cmi[i].ligs) {
+	       ligs = fi->cmi[i].ligs;
+	       while (ligs) {
 		    Ligature *tmp;
-		    tmp = fi->cmi[i].ligs;
+		    tmp = ligs;
+		    ligs = ligs->next;
 		    free (tmp->succ);
 		    free (tmp->lig);
 		    free (tmp);
-		    fi->cmi[i].ligs = fi->cmi[i].ligs->next;
 	       }
 	  }
 	  free (fi->cmi);
